Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / dataknobs_common / exceptions.py |  | 23 | 3 | 0 |  | 87%
src / dataknobs_common / registry.py |  | 281 | 213 | 9 |  | 24%
src / dataknobs_common / serialization.py |  | 42 | 27 | 0 |  | 36%
src / dataknobs_common / testing.py |  | 83 | 16 | 0 |  | 81%
Total |  | 429 | 259 | 9 |  | 40%

No items found using the specified filter.